package de.intevation.flys.importer;

import java.util.ArrayList;
import java.util.List;

import org.apache.log4j.Logger;

import org.hibernate.Session;
import org.hibernate.Query;

import de.intevation.flys.model.WaterlevelDifference;
import de.intevation.flys.model.WaterlevelDifferenceColumn;


public class ImportWaterlevelDifferenceColumn {

    private static final Logger log =
        Logger.getLogger(ImportWaterlevelDifferenceColumn.class);


    private String description;

    private List<ImportWaterlevelDifferenceValue> values;

    private WaterlevelDifferenceColumn peer;


    public ImportWaterlevelDifferenceColumn(String description) {
        this.values = new ArrayList<ImportWaterlevelDifferenceValue>();

        this.description = description;
    }


    public String getDescription() {
        return description;
    }


    public void addValue(ImportWaterlevelDifferenceValue value) {
        this.values.add(value);
    }

    public List<ImportWaterlevelDifferenceValue> getValues() {
        return values;
    }

    public void storeDependencies(WaterlevelDifference difference) {
        log.info("store dependencies");

        WaterlevelDifferenceColumn peer = getPeer(difference);

        int i = 0;

        for (ImportWaterlevelDifferenceValue value: values) {
            value.storeDependencies(peer);
            i++;
        }

        log.info("stored " + i + " waterlevel difference values");
    }


    public WaterlevelDifferenceColumn getPeer(WaterlevelDifference diff) {
        if (peer == null) {
            Session session = ImporterSession.getInstance().getDatabaseSession();
            Query query = session.createQuery(
                "from WaterlevelDifferenceColumn where " +
                "   difference=:difference and " +
                "   description=:description"
            );

            query.setParameter("difference", diff);
            query.setParameter("description", description);

            List<WaterlevelDifferenceColumn> cols = query.list();
            if (cols.isEmpty()) {
                peer = new WaterlevelDifferenceColumn(diff, description);
                session.save(peer);
            }
            else {
                peer = cols.get(0);
            }
        }

        return peer;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
